@@ -1,22 +1,22 @@
 package Sisimai::Rhost::Mimecast;
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 use Sisimai::SMTP::Reply;
 
-sub get {
+sub find {
     # Detect bounce reason from https://www.mimecast.com/
-    # @param    [Sisimai::Fact] argvs   Parsed email object
+    # @param    [Sisimai::Fact] argvs   Decoded email object
     # @return   [String]                The bounce reason at Mimecast
     # @since v4.25.15
     my $class = shift;
     my $argvs = shift // return undef;
-
-    return undef unless length $argvs->{'diagnosticcode'};
-    return undef unless Sisimai::SMTP::Reply->test($argvs->{'replycode'});
+    return '' unless $argvs->{'diagnosticcode'};
+    return '' unless Sisimai::SMTP::Reply->test($argvs->{'replycode'});
 
     state $messagesof = {
         # https://community.mimecast.com/s/article/Mimecast-SMTP-Error-Codes-842605754
+        # https://community.mimecast.com/s/article/email-security-cloud-gateway-mimecast-smtp-error-codes
         'authfailure' => [
             # - The inbound message has been rejected because the originated IP address isn't list-
             #   ed in the published SPF records for the sending domain.
@@ -76,6 +76,41 @@ sub get {
             #   the associated IP address from the RBL.
             #[550, '< details of RBL >'], NEED AN ACTUAL ERROR MESSAGE STRING
         ],
+        'expired' => [
+            # - Journal messages past the expiration
+            # - Attempts are being made to journal mail past the set expiry threshold.
+            #   A retry response will replace the failure because the message is marked for retry
+            #   if rejected, causing the journal queue to grow.
+            # - Check to confirm there are no significant time discrepancies on the mail server.
+            #   Discontinue journaling old messages past the expiry threshold.
+            [550, 'Journal messages past the expiration'],
+        ],
+        'failedstarttls' => [
+            # - This email has been sent using SMTP, but TLS is required by policy.
+            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
+            #   Alternatively, ensure the certificates on the mail server haven't expired. If using
+            #   a proxy server, ensure it isn't intercepting the traffic and modifying encryption
+            #   parameters.
+            [553, 'this route requires encryption (tls)'],
+
+            # - A TLS connection has been attempted using a TLS version that is lower than TLS 1.2.
+            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
+            #   Alternatively, ensure the mail server attempting to connect is using the appropri-
+            #   ate version of TLS.
+            [553, 'this route requires tls version 1.2 or greater'],
+
+            # - A secure connection was attempted using ciphers that do not meet the configured ci-
+            #   pher strength.
+            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS. Alter-
+            #   natively, ensure the certificates on the mail server haven't expired. If using a
+            #   proxy server, ensure it isn't intercepting the traffic and modifying encryption
+            #   parameters.
+            [553, 'this route requires high-strength ciphers'],
+
+            # - Validation on your umbrella account's domain name does not conform to your DNS.
+            # - Check you DNS has the required umbrella accounts listed as comma-separated values.
+            [554, 'configuration is invalid for this certificate'],
+        ],
         'mesgtoobig' => [
             # - The email size either exceeds an Email Size Limit policy or is larger than the
             #   Mimecast service limit. The default is 100 MB for the Legacy MTA, and 200 MB for
@@ -86,6 +121,12 @@ sub get {
             [554, 'maximum email size exceeded'],
         ],
         'networkerror' => [
+            # - The recipients' domains have MX records configured incorrectly
+            # - Check and remove any MX records that point to hostnames with outbound references.
+            #   Only Inbound smart hosts are supported on MX records.
+            [451, 'the incorrect hostname used for inbounds'],
+            [550, 'the incorrect hostname used for inbounds'],
+
             # - The message has too many "received headers" as it has been forwarded across multi-
             #   ple hops. Once 25 hops have been reached, the email is rejected.
             # - Investigate the email addresses in the communication pairs, to see what forwarders
@@ -99,6 +140,7 @@ sub get {
             # - Mimecast customers should contact Mimecast Support to add the Authorized Outbound
             #   address, or to take other remedial action.
             [451, 'open relay not allowed'],
+            [451, 'open relay is not allowed'],
         ],
         'notaccept' => [
             # - The customer account Inbound emails are disabled in the Administration Console.
@@ -136,6 +178,7 @@ sub get {
             # - The message has triggered a Geographical Restriction policy.
             # - Delete or amend the policy.
             [554, 'host network not allowed'],
+            [554, 'host network, not allowed'],
         ],
         'rejected' => [
             # - The sender's email address or domain has triggered a Blocked Senders Policy or
@@ -145,8 +188,8 @@ sub get {
 
             # - A personal block policy is in place for the email address/domain.
             # - Remove the email address/domain from the Managed Senders list.
-            [550, 'envelope blocked – user entry'],
-            [550, 'envelope blocked – user domain entry'],
+            [550, 'envelope blocked - user entry'],
+            [550, 'envelope blocked - user domain entry'],
             [550, 'rejected by header-based manually blocked senders - block for manual block'],
 
             # - A Block Sender Policy has been applied to reject emails based on the Header From or
@@ -163,31 +206,7 @@ sub get {
             #   sage on SMTP port 25.
             [535, 'incorrect authentication data'],
             [550, 'submitter failed to disabled'],
-
-            # - This email has been sent using SMTP, but TLS is required by policy.
-            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
-            #   Alternatively, ensure the certificates on the mail server haven't expired. If using
-            #   a proxy server, ensure it isn't intercepting the traffic and modifying encryption
-            #   parameters.
-            [553, 'this route requires encryption (tls)'],
-
-            # - A TLS connection has been attempted using a TLS version that is lower than TLS 1.2.
-            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS.
-            #   Alternatively, ensure the mail server attempting to connect is using the appropri-
-            #   ate version of TLS.
-            [553, 'this route requires tls version 1.2 or greater'],
-
-            # - A secure connection was attempted using ciphers that do not meet the configured ci-
-            #   pher strength.
-            # - Delete or change the Secure Receipt or Secure Delivery policy enforcing TLS. Alter-
-            #   natively, ensure the certificates on the mail server haven't expired. If using a
-            #   proxy server, ensure it isn't intercepting the traffic and modifying encryption
-            #   parameters.
-            [553, 'this route requires high-strength ciphers'],
-
-            # - Validation on your umbrella account's domain name does not conform to your DNS.
-            # - Check you DNS has the required umbrella accounts listed as comma-separated values.
-            [554, 'configuration is invalid for this certificate'],
+            [550, 'submitter failed to authenticate'],
         ],
         'systemerror' => [
             # - The Mimecast server is under maximum load.
@@ -297,19 +316,19 @@ Sisimai::Rhost::Mimecast - Detect the bounce reason returned from Mimecast
 
 =head1 SYNOPSIS
 
-    use Sisimai::Rhost;
+    use Sisimai::Rhost::Mimecast;
 
 =head1 DESCRIPTION
 
-Sisimai::Rhost detects the bounce reason from the content of Sisimai::Fact object as an argument of
-get() method when the value of C<rhost> or C<destination> of the object is "mimecast.com". This
-class is called only Sisimai::Fact class.
+C<Sisimai::Rhost::Mimecast> detects the bounce reason from the content of C<Sisimai::Fact> object
+as an argument of C<find()> method when the value of C<rhost> or C<destination> of the object is
+C<mimecast.com>. This class is called only C<Sisimai::Fact> class.
 
 =head1 CLASS METHODS
 
-=head2 C<B<get(I<Sisimai::Fact Object>)>>
+=head2 C<B<find(I<Sisimai::Fact Object>)>>
 
-C<get()> detects the bounce reason.
+C<find()> method detects the bounce reason.
 
 =head1 AUTHOR
 
@@ -317,7 +336,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022 azumakuniyuki, All rights reserved.
+Copyright (C) 2022-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
